<?php
/**
 * Plugin Name: WIPAY-Voucher
 * Plugin URI: http://wipayfinancial.com
 * Description: WIPAY is payment gateway for WooCommerce allowing you to take payments via wipayfinancial.com and purchasable top-ups.
 * Version: 1.0
 * Author: Shiva Ramdeen
 * Author URI: http://www.wipayfinancial.com/
 */ 


add_action( 'plugins_loaded', 'init_sr_woo_gateway_v', 0);

function wiv_settings( $links ) {
    $settings_link = '<a href="'.admin_url( 'admin.php?page=wc-settings&tab=checkout&section=wc_gateway_js_wipay_voucher' ).'">Setup</a>';
  	array_push( $links, $settings_link );
  	return $links;
}
$plugin = plugin_basename( __FILE__ );
add_filter( "plugin_action_links_$plugin", 'wiv_settings' );

function init_sr_woo_gateway_v(){

	if ( ! class_exists( 'WC_Payment_Gateway' ) ) return;

	class WC_Gateway_JS_WIPAY_VOUCHER extends WC_Payment_Gateway {

		var $seller_id;
        var $sandbox_enabled;
		
		var $plugin_url;

		public function __construct(){
			
			global $woocommerce;

			$this -> plugin_url = WP_PLUGIN_URL . DIRECTORY_SEPARATOR . 'woocommerce-wipay-voucher';
			
			$this->id 					= 'wipay_voucher';
			$this->has_fields   		= true;//we want to display the voucher number field on the checkout page
            $this->checkout_url     	= 'https://wipayfinancial.com/v1/voucher_pay'; //live url
			$this->checkout_url_sandbox	= 'https://wipaytoday.com/v1/voucher_pay'; //sandbox url
			$this->icon 				= $this -> plugin_url.'/images/logo.png';
			$this->method_title 		= 'WIPAY Voucher';
            
            $this->title 				= 'WIPAY Voucher';
			$this->seller_id			= $this->get_option( 'seller_id' );
			// $this->api_key			    = $this->get_option( 'api_key' ); //voucher doesn't need this
            $this->sandbox_enabled		= $this->get_option( 'sandbox_enabled' );
			
				
			$this->init_form_fields();
			$this->init_settings();
				
			// Save options
			add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
				
		}


		function init_form_fields(){

			$this->form_fields = array(
					'enabled' => array(
							'title' => __( 'Enable', 'woocommerce' ),
							'type' => 'checkbox',
							'label' => __( 'Yes', 'woocommerce' ),
							'default' => 'yes'
					),
                    'sandbox_enabled' => array(
							'title' => __( 'Enable Sandbox', 'woocommerce' ),
							'type' => 'checkbox',
							'label' => __( 'Yes', 'woocommerce' ),
							'default' => 'yes'
					),
					'seller_id' => array(
							'title' => __( 'WIPAY Developer ID', 'woocommerce' ),
							'type' => 'text',
							'description' => __( 'This Developer ID issued by WIPAY', 'woocommerce' ),
							'default' => '',
							'desc_tip'      => true,
					),
					// 'api_key' => array(
					// 		'title' => __( 'API KEY', 'woocommerce' ),
		            //         'type' 			=> 'text',
		            //         'description' => __( 'Please enter your WIPAY API KEY.', 'woocommerce' ),
		            //         'default' => '',
		            //         'desc_tip'      => true,
		            //         'placeholder'	=> ''
					// ),
			);
		}

		public function payment_fields(){
			// reproduce/modify this function in your class
			echo "<fieldset>
			<legend>Wipay Top-up Voucher:</legend> <input id=\"voucher\" name=\"token\" type=\"text\" placeholder=\"Voucher Number\" required> </fieldset>";
		}


		/**
		 * Process the payment and return the result
		 *
		 * @access public
		 * @param int $order_id
		 * @return array
		 */
		function process_payment( $order_id ) {

			//get parameters for contacting wipay voucher api

			$order = new WC_Order( $order_id );


			$twoco_args = $this->get_twoco_args( $order );
		
			
			$twoco_args = http_build_query( $twoco_args, '', '&' );
				
			
            
            //use sandbox for testing
			if($this->sandbox_enabled  == "yes"){
            $checkout_url =	$this->checkout_url_sandbox;
            }else{
            $checkout_url =	$this->checkout_url;
			}
			
			//process payment
			$response = $this->process_wipay_voucher($checkout_url,$twoco_args);
			$json = json_decode($response);
			
			if($json->status === "error"){
				wc_add_notice("There was a problem processing your order with Wipay. Error: ".$json->msg, 'error' );
				return array(
					'result' 	=> 'failure',
					'redirect'	=> wc_get_cart_url(),
				);
			}
			else if($json->status === "success"){
				global $woocommerce;
				$wc_order 	= $order;
				//reduce stock
				$wc_order->reduce_order_stock();				
				// Mark order complete
				$wc_order->payment_complete();
				// Empty cart and clear session
				$woocommerce->cart->empty_cart();

				return array(
					'result' 	=> 'success',
					'redirect'	=> $this->get_return_url( $wc_order ),
				);
			}

			

		}


		/**
		 *
		 * @access public
		 * @param mixed $order
		 * @return array
		 */
		function get_twoco_args( $order ) {
			
			global $woocommerce;
			$order_id = $order->id;
			$transaction_fee = 5.00;

			// arguments
			$twoco_args = array(
					'developer_id' 			=> $this->seller_id,
					'order_id'		        => $order_id,
					'currency_code'			=> get_woocommerce_currency(),
                
						
					// Billing Address info
					'name'			        => $order->billing_first_name . ' ' . $order->billing_last_name,
					'email'					=> $order->billing_email,
					'phone'					=> $order->billing_phone,
					'voucher'					=> $_POST['token'],
					
			);
			
			$twoco_args['total'] =     $woocommerce->cart->total - $transaction_fee;
			if($woocommerce->cart->total == 0){		
            $twoco_args['total'] = WC_Payment_Gateway::get_order_total();
			}
			
	        $twoco_args = apply_filters( 'woocommerce_twoco_args', $twoco_args );
            


			return $twoco_args;
		}
		
		//contact wipay voucher api and process payment
		function process_wipay_voucher($checkout_url,$twoco_args)
		{
			$service_url = $checkout_url;
			$curl = curl_init($service_url);
			$curl_post_data = $twoco_args;
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, CURLOPT_POST, true);
			curl_setopt($curl, CURLOPT_POSTFIELDS, $curl_post_data);
			$curl_response = curl_exec($curl);
			curl_close($curl);
			return $curl_response;
		}
		
		
	
	}
	
}


function add_nm_payment_gateway_v( $methods ) {
	$methods[] = 'WC_Gateway_JS_WIPAY_VOUCHER';
	return $methods;
}
add_filter( 'woocommerce_payment_gateways', 'add_nm_payment_gateway_v' );
?>